#### Gene regulatory network analysis ####
To investigate CAR-T regulatory pathways activated by different treatments, we ran **SCENIC** which is a computational method to infer Gene Regulatory Networks (GRN) from scRNA-seq data.</br>
In details, starting from the UMI count matrix, the potential targets of the same transcription factor (TF) (gene regulatory networks) are identified based on co-expression using the GRNBoost algorithm and then potential direct-binding targets (regulons) are selected based on DNA-motif analysis (i.e., TF motif analysis). Finally, the network activity of regulons is computed in each individual cell and combined to obtain the average regulon activity by treatment group.

- Full_CART_metadata.xlsx: file containing the meta-data of the CART Seurat object.
- Full_CART_HM_regulonActivity.xlsx: file containing the regulon activity shown in the heatmap.
- SCENIC_CART_HM.R: R script to produce the heatmap on the results of the SCENIC analysis.

![Full_CART_HM](./Full_CART_HM.png)

---

#### SCENIC Analyis ####

1. Convert Seurat object into _loom_: `Rscript export_loom.R <Full_CART.rds> <Full_CART.loom>`

2. Gene regulatory network inference: `pyscenic grn --num_workers 8 -output <Full_CART.adjacences.tsv> --method grnboost2 <Full_CART.loom> mm_tfs.txt`

3. Regulon prediction: `pyscenic ctx --annotations_fname motifs-v9-nr.mgi-m0.001-o0.0.tbl --expression_mtx_fname <Full_CART.loom> --mode 'dask_multiprocessing' --num_workers 8 --output <Full_CART.regulons.tsv> <Full_CART.adjacences.tsv> mm9-500bp-upstream-10species.mc9nr.genes_vs_motifs.rankings.feather mm9-tss-centered-5kb-10species.mc9nr.genes_vs_motifs.rankings.feather mm9-tss-centered-10kb-10species.mc9nr.genes_vs_motifs.rankings.feather`

4. Cellular enrichment: `pyscenic aucell --num_workers 8 --output <Full_CART.from_tsv.loom> <Full_CART.loom> <Full_CART.regulons.tsv>`
